@@ -34,6 +34,7 @@ class Surface:
                 temp.delta.values,
                 temp.dte,
                 temp.strike.values,
+                self.putCall,
                 desc,
             )
             self.curves.append(curve)
@@ -82,12 +83,13 @@ class Surface:
 
 
 class Curve:
-    def __init__(self, markIvs, deltas, dte, strikes, desc):
+    def __init__(self, markIvs, deltas, dte, strikes, putCall, desc):
         # Assumes deltas are sorted
         self.markIvs = markIvs
         self.deltas = deltas
         self.dte = dte.min()
         self.desc = desc
+        self.putCall = putCall
         self.strikes = strikes
         assert len(markIvs) == len(deltas), "length mismatch"
 
@@ -144,6 +146,7 @@ class Curve:
         # Reverse the strikes if call.
         should_reverse = -1 if self.putCall == "C" else 1
         for idx in range(len(self.strikes))[::should_reverse]:
+            print(idx)
             if strike < self.strikes[idx]:
                 lowestIv = self.markIvs[idx]
                 lowestStrike = self.strikes[idx]
@@ -152,7 +155,15 @@ class Curve:
                 highestIv = self.markIvs[idx]
                 highestStrike = self.strikes[idx]
 
-        print(highestIv, highestStrike, lowestIv, lowestStrike)
+        print(
+            highestIv,
+            highestStrike,
+            lowestIv,
+            lowestStrike,
+            self.putCall,
+            should_reverse,
+        )
+        print(self.strikes, self.markIvs)
         if lowestStrike == 0:
             return self.markIvs[idx]
         elif highestStrike == 0:
